This is an automated email from the git hooks/post-receive script.
lfam pushed a commit to branch master
in repository guix.
The following commit(s) were added to refs/heads/master by this push:
new 8bc831325a services: syncthing: Fix typo in file name.
8bc831325a is described below
commit 8bc831325a905dbd9015739b58e3a5138d2217da
Author: Leo Famulari <[email protected]>
AuthorDate: Tue Feb 25 13:05:53 2025 -0500
services: syncthing: Fix typo in file name.
This is a followup to commit 651f8765b657e35baf85ac74a1f6b09ff71691cb
* gnu/services/syncthing.scm (syncthing-files-service): Fix typo.
Change-Id: I55d1d480d356f41e65b85f8503ceb38c5c1a021b
---
gnu/services/syncthing.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/services/syncthing.scm b/gnu/services/syncthing.scm
index 46333fcb0f..efafec8f73 100644
--- a/gnu/services/syncthing.scm
+++ b/gnu/services/syncthing.scm
@@ -539,13 +539,13 @@
;; When used as a system service, this service might be executed
;; before a user's home even exists, causing it to be owned by root,
;; and the skeletons to never be applied to that user's home. In such
;; cases, put the config at /var/lib/syncthnig-<user>/config.xml
`((,(if home-service?
".config/syncthing/config.xml"
(string-append "/var/lib/syncthing-" user "/config.xml"))
,(if (file-like? config-file)
config-file
- (plain-file "syncthin-config.xml"
(serialize-syncthing-config-file
+ (plain-file "syncthing-config.xml"
(serialize-syncthing-config-file
config-file)))))
'())))
@@ -539,13 +539,13 @@
;; before a user's home even exists, causing it to be owned by root,
;; and the skeletons to never be applied to that user's home. In such
- ;; cases, put the config at /var/lib/syncthnig-<user>/config.xml
+ ;; cases, put the config at /var/lib/syncthing-<user>/config.xml
`((,(if home-service?
".config/syncthing/config.xml"